@@ -36,7 +36,7 @@ test_that("can pin an xgboost model", {
 })
 
 test_that("default endpoint for xgboost", {
-    p <- pr() %>% vetiver_pr_predict(v)
+    p <- pr() %>% vetiver_api(v)
     expect_equal(names(p$routes), c("ping", "predict"))
     expect_equal(map_chr(p$routes, "verbs"),
                  c(ping = "GET", predict = "POST"))
@@ -44,7 +44,7 @@ test_that("default endpoint for xgboost", {
 
 test_that("default OpenAPI spec", {
     v$metadata <- list(url = "potatoes")
-    p <- pr() %>% vetiver_pr_predict(v)
+    p <- pr() %>% vetiver_api(v)
     car_spec <- p$getApiSpec()
     expect_equal(car_spec$info$description,
                  "An xgboost reg:squarederror model")
